==> freecad_0.20.2+dfsg1.orig.tar.xz: FreeCAD-0.20.2/src/Mod/Web/Gui/Resources/translations/Web_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="72"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="73"/>
      <source>Previous page</source>
      <translation>Pàgina anterior</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="74"/>
      <source>Go back to the previous page</source>
      <translation>Tornar a la pàgina anterior</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="101"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Next page</source>
      <translation>Pàgina següent</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Go to the next page</source>
      <translation>Anar a la pàgina següent</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="130"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="131"/>
      <location filename="../../Command.cpp" line="132"/>
      <source>Refresh web page</source>
      <translation>Actualitzar la pàgina web</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserSetURL</name>
    <message>
      <location filename="../../Command.cpp" line="246"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="247"/>
      <location filename="../../Command.cpp" line="248"/>
      <source>Set URL</source>
      <translation>Estableix l'URL</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="158"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="159"/>
      <location filename="../../Command.cpp" line="160"/>
      <source>Stop loading</source>
      <translation>Aturar la carrega</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="188"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="189"/>
      <location filename="../../Command.cpp" line="190"/>
      <source>Zoom in</source>
      <translation>Ampliar</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="217"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="218"/>
      <location filename="../../Command.cpp" line="219"/>
      <source>Zoom out</source>
      <translation>Allunyar</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="46"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="47"/>
      <source>Open website...</source>
      <translation>Obrir web...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="48"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Obra una pàgina web a FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../BrowserView.cpp" line="785"/>
      <location filename="../../AppWebGui.cpp" line="85"/>
      <source>Browser</source>
      <translation>Navegador</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="597"/>
      <source>File does not exist!</source>
      <translation>El fitxer no existeix!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="585"/>
      <location filename="../../BrowserView.cpp" line="590"/>
      <location filename="../../BrowserView.cpp" line="593"/>
      <source>Error</source>
      <translation>Error</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="590"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>Hi hagué errors quan es carregava el fitxer. Algunes dades s'han pogut modificar o no s'han recuperat. Cerqueu a la vista d'informes per a obtindre informació més específica sobre els objectes implicats.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="593"/>
      <source>There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</source>
      <translation>Hi ha hagut greus errors en carregar l'arxiu. Pot ser que s'hagin modificat dades o no s'hagin recuperat. Guardar el projecte molt probablement resulti en pèrdua de dades.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="753"/>
      <source>Loading %1...</source>
      <translation>Carregant 1%...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="351"/>
      <source>Open in External Browser</source>
      <translation>Obrir en un Navegador Extern</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="355"/>
      <source>Open in new window</source>
      <translation>Obrir en una finestra nova</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="387"/>
      <source>View source</source>
      <translation>Visualitza la font</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>Navigation</source>
      <translation>Navegació</translation>
    </message>
  </context>
</TS>

==> freecad_0.21.2+dfsg1.orig.tar.xz: FreeCAD-0.21.2/src/Mod/Web/Gui/Resources/translations/Web_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="72"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="73"/>
      <source>Previous page</source>
      <translation>Pàgina anterior</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="74"/>
      <source>Go back to the previous page</source>
      <translation>Torna a la pàgina anterior</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="101"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Next page</source>
      <translation>Pàgina següent</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Go to the next page</source>
      <translation>Ves a la pàgina següent</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="130"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="131"/>
      <location filename="../../Command.cpp" line="132"/>
      <source>Refresh web page</source>
      <translation>Actualitza la pàgina web</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserSetURL</name>
    <message>
      <location filename="../../Command.cpp" line="246"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="247"/>
      <location filename="../../Command.cpp" line="248"/>
      <source>Set URL</source>
      <translation>Estableix l'URL</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="158"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="159"/>
      <location filename="../../Command.cpp" line="160"/>
      <source>Stop loading</source>
      <translation>Atura la càrrega</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="188"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="189"/>
      <location filename="../../Command.cpp" line="190"/>
      <source>Zoom in</source>
      <translation>Apropa</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="217"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="218"/>
      <location filename="../../Command.cpp" line="219"/>
      <source>Zoom out</source>
      <translation>Allunya</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="46"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="47"/>
      <source>Open website...</source>
      <translation>Obre el lloc web...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="48"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Obre un lloc web al FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../BrowserView.cpp" line="815"/>
      <location filename="../../AppWebGui.cpp" line="93"/>
      <source>Browser</source>
      <translation>Navegador</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="623"/>
      <source>File does not exist!</source>
      <translation>El fitxer no existeix!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="611"/>
      <location filename="../../BrowserView.cpp" line="616"/>
      <location filename="../../BrowserView.cpp" line="619"/>
      <source>Error</source>
      <translation>Error</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="616"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>S'han produït errors en carregar el fitxer. Algunes dades es poden haver modificat o no s'han recuperat. Consulteu la vista d'informe per a obtenir informació més específica sobre els objectes implicats.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="619"/>
      <source>There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</source>
      <translation>Hi ha hagut errors greus en carregar el fitxer. Pot ser que s'hagin modificat dades o no s'hagin recuperat. Desar el projecte probablement provocarà la pèrdua de dades.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="783"/>
      <source>Loading %1...</source>
      <translation>S'està carregant %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="362"/>
      <source>Open in External Browser</source>
      <translation>Obre en un navegador extern</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="365"/>
      <source>Open in new window</source>
      <translation>Obre en una finestra nova</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="411"/>
      <source>View source</source>
      <translation>Visualitza la font</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="36"/>
      <source>Navigation</source>
      <translation>Navegació</translation>
    </message>
  </context>
</TS>
